"""FHIR Agent Tools - LLM-agent-ready extraction functions for FHIR JSON resources."""

from fhir_agent_tools._parse import FhirExtractError
from fhir_agent_tools.patient import (
    get_patient_address,
    get_patient_identifiers,
    get_patient_name,
    get_patient_summary,
    get_patient_telecom,
)
from fhir_agent_tools.practitioner import (
    get_practitioner_identifiers,
    get_practitioner_name,
    get_practitioner_summary,
)
from fhir_agent_tools.bundle import (
    get_bundle_entries,
    get_bundle_total,
    get_resources_by_type,
)
from fhir_agent_tools.tools import get_extractor_functions, get_tools

__all__ = [
    "FhirExtractError",
    "get_patient_summary",
    "get_patient_name",
    "get_patient_identifiers",
    "get_patient_telecom",
    "get_patient_address",
    "get_practitioner_summary",
    "get_practitioner_name",
    "get_practitioner_identifiers",
    "get_bundle_entries",
    "get_resources_by_type",
    "get_bundle_total",
    "get_tools",
    "get_extractor_functions",
]
